@@ -1,6 +1,6 @@
 package Crypt::TimestampedData;
-$Crypt::TimestampedData::VERSION = '0.01_02'; # TRIAL
-$Crypt::TimestampedData::VERSION = '0.0102';
+$Crypt::TimestampedData::VERSION = '0.01_03'; # TRIAL
+$Crypt::TimestampedData::VERSION = '0.0103';
 use strict;
 use warnings;
 
@@ -14,7 +14,7 @@ Crypt::TimestampedData - Read and write TimeStampedData files (.TSD, RFC 5544)
 
 =head1 VERSION
 
-version 0.01_02
+version 0.01_03
 
 =head1 SYNOPSIS
 
@@ -114,6 +114,40 @@ TimeStampToken(s) provided as .TSR (DER CMS ContentInfo) blobs or paths.
     'document.tsd'           # output file
   );
 
+=head1 COMMAND-LINE SCRIPTS
+
+This distribution includes several command-line scripts for working with TimeStampedData files:
+
+=over 4
+
+=item * C<tsd-create> - Create a .tsd file from a file and timestamp
+
+=item * C<tsd-extract> - Extract content and timestamps from a .tsd file
+
+=item * C<tsd-info> - Display information about a .tsd file
+
+=item * C<tsd-timestamp> - Obtain a timestamp from FreeTSA.org
+
+=back
+
+=head2 Windows Usage
+
+On Windows systems, scripts must be executed with Perl explicitly:
+
+  perl tsd-create --help
+  perl tsd-extract document.tsd
+  perl tsd-info document.tsd
+  perl tsd-timestamp document.pdf
+
+=head2 Unix/Linux Usage
+
+On Unix/Linux systems, scripts can be executed directly:
+
+  tsd-create --help
+  tsd-extract document.tsd
+  tsd-info document.tsd
+  tsd-timestamp document.pdf
+
 =head1 REQUIREMENTS
 
 =over 4
